<?php
/**
 * Top X Stats (topxstats_)
 *
 * @file ./topxstats_source/resources/main_requests.php
 * @author Labradoodle-360 <creativewebdsign@gmail.com>
 * @copyright Matthew Kerle, 2013
 *
 * @version 1.0.1
 */

if (!defined('SMF'))
	die('Hacking attempt...');

function topxstats_latest_members($num_stats, $show_color = false)
{
	global $smcFunc;
	$latest_members = array();
	$query = array(
		'columns' => 'mem.id_member, mem.real_name, mem.posts, mem.date_registered',
		'sources' => '{db_prefix}members AS mem'
	);
	if ($show_color === true)
	{
		$query['columns'] .= ', mgroup.online_color';
		$query['sources'] .= ' LEFT JOIN {db_prefix}membergroups AS mgroup ON (mgroup.id_group = mem.id_group)';
	}
	$request = $smcFunc['db_query']('', '
		SELECT ' . $query['columns'] . '
		FROM ' . $query['sources'] . '
		ORDER BY mem.date_registered DESC
		LIMIT {int:this_limit}',
		array(
			'this_limit' => $num_stats
		)
	);
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$row['online_color'] = !isset($row['online_color']) ? '' : $row['online_color'];
		$latest_members[$row['id_member']] = array(
			'link' => topxstats_format_link($row['id_member'], $row['real_name'], $row['online_color']),
			'datetime_registered' => timeformat($row['date_registered'])
		);
	}	
	$smcFunc['db_free_result']($request);
	return $latest_members;
}

function topxstats_latest_posts($num_stats, $show_color = false)
{
	global $scripturl, $smcFunc, $modSettings;
	$latest_posts = array();
	$query = array(
		'where' => '{query_wanna_see_board}',
		'columns' => '',
		'sources' => ''
	);
	if (!empty($modSettings['recycle_enable']) && $modSettings['recycle_board'] > 1)
		$query['where'] .= ' AND b.id_board != {int:recycle_board}';
	$query['where'] .= ' AND m.approved = {int:is_approved}';
	if ($show_color === true)
	{
		$query['columns'] .= ', mg.online_color';
		$query['sources'] .= ' LEFT JOIN {db_prefix}membergroups AS mg ON (mg.id_group = mem.id_group)';
	}
	$request = $smcFunc['db_query']('', '
		SELECT
			m.id_msg, m.subject, m.poster_time, b.name AS bname,
			m.id_topic, m.id_member, m2.id_member AS id_first_member,
			t.id_first_msg, t.id_board, t.id_last_msg,
			IFNULL(mem2.real_name, m2.poster_name) AS first_poster_name,
			IFNULL(mem.real_name, m.poster_name) AS poster_name
			' . $query['columns'] . '
		FROM {db_prefix}messages AS m
			INNER JOIN {db_prefix}topics AS t ON (t.id_topic = m.id_topic)
			INNER JOIN {db_prefix}boards AS b ON (b.id_board = t.id_board)
			INNER JOIN {db_prefix}messages AS m2 ON (m2.id_msg = t.id_first_msg)
			LEFT JOIN {db_prefix}members AS mem ON (mem.id_member = m.id_member)
			LEFT JOIN {db_prefix}members AS mem2 ON (mem2.id_member = m2.id_member)
			' . $query['sources'] . '
		WHERE ' . $query['where'] . '
		ORDER BY m.id_msg DESC
		LIMIT {int:this_limit}',
		array(
			'recycle_board' => $modSettings['recycle_board'],
			'is_approved' => 1,
			'this_limit' => $num_stats
		)
	);
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$row['online_color'] = !isset($row['online_color']) ? '' : $row['online_color'];
		$latest_posts[$row['id_msg']] = array(
			'link' => '<a href="' . $scripturl . '?topic=' . $row['id_topic'] . '.new;topicseen#new" target="_self" title="' . $row['subject'] . '">' . shorten_subject($row['subject'], 20) . '</a>',
			'datetime_stamp' => timeformat($row['poster_time']),
			'member' => array(
				'link' => topxstats_format_link($row['id_member'], $row['poster_name'], $row['online_color'])
			)
		);
	}
	$smcFunc['db_free_result']($request);
	return $latest_posts;
}

function topxstats_top_posters($num_stats, $show_color = false)
{
	global $smcFunc;
	$top_posters = array();
	$query = array(
		'columns' => 'mem.id_member, mem.real_name, mem.posts',
		'sources' => '{db_prefix}members AS mem',
		'where' => 'mem.posts >= {int:one}'
	);
	if ($show_color === true)
	{
		$query['columns'] .= ', mgroup.online_color';
		$query['sources'] .= ' LEFT JOIN {db_prefix}membergroups AS mgroup ON (mgroup.id_group = mem.id_group)';
	}
	$request = $smcFunc['db_query']('', '
		SELECT ' . $query['columns'] . '
		FROM ' . $query['sources'] . '
		WHERE ' . $query['where'] . '
		ORDER BY mem.posts DESC
		LIMIT {int:this_limit}',
		array(
			'this_limit' => $num_stats,
			'one' => 1
		)
	);
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$row['online_color'] = !isset($row['online_color']) ? '' : $row['online_color'];
		$top_posters[$row['id_member']] = array(
			'link' => topxstats_format_link($row['id_member'], $row['real_name'], $row['online_color']),
			'posts' => $row['posts']
		);
	}
	$smcFunc['db_free_result']($request);
	return $top_posters;
}

function topxstats_stats_sum($latest_members = 0, $latest_posts = 0, $top_posters = 0)
{
	return (count($latest_members) + count($latest_posts) + count($top_posters));
}

function topxstats_format_link($mem_id, $real_name, $group_color = null, $target = 'self')
{
	global $scripturl;
	return '<a href="' . $scripturl . '?action=profile;u=' . $mem_id . '" target="_' . $target . '" title="' . $real_name . '"' . (!empty($group_color) ? ' style="color: ' . $group_color . ';"' : '') . '>' . shorten_subject($real_name, 16) . '</a>';
}